@@ -510,11 +510,9 @@ public class Imager {
 		// scale must be the same of all images.
 		if (count == 1  && Settings.has("rgb")  && Settings.has("scale")) {
 		    scale = Settings.get("scale");
-                    System.err.println("Getting scale..."+scale);
 		}
 		Settings.restore();
 		if (scale != null) {
-                    System.err.println("Putting scale:"+scale);
 		    Settings.put("scale", scale);
 		}
 	    }
