@@ -191,7 +191,7 @@ public class Clip extends Sampler {
     /** Calculate the area of a convex polygon.
      * This function calculates the area of a convex polygon
      * by deconvolving the polygon into triangles and summing
-     * the areas of the consituents.  The user provides the
+     * the areas of the constituents.  The user provides the
      * coordinates of the vertices of the polygon in sequence
      * along the circumference (in either direction and starting
      * at any point).
@@ -465,7 +465,6 @@ public class Clip extends Sampler {
      */
     public void sample(int pix) {
 	
-//	((skyview.geometry.Converter)trans).debug(true);
 	double[][] in = outImage.getCorners(pix);
 	
 	try {
@@ -501,7 +500,7 @@ public class Clip extends Sampler {
 	    depthArray[z] = 0;
 	}
 	tArea=0;
-	accumulate(pix, x, y);
+	accumulate(pix, x, y, false);
 	
 	if (intensive  && tArea > 0) {
 	    for (int z=0; z<inDepth; z += 1) {
@@ -516,7 +515,26 @@ public class Clip extends Sampler {
 	
     }
     
-    private void accumulate(int pix, double[] x, double[] y) {
+    // If we have straddled then roundoff errors may cause real problems...
+    void checkXY(double[] xa, double[] ya) {
+        for (int i=0; i<xa.length; i += 1) {
+            double x = xa[i];
+            double y = ya[i];
+            if (x - Math.floor(x) < 3*Math.ulp(x)) {
+                x = Math.floor(x);
+            } else if (Math.ceil(x) - x < 3*Math.ulp(x)) {
+                x = Math.ceil(x);
+            }
+            if (y - Math.floor(y) < 3*Math.ulp(y)) {
+                y = Math.floor(y);
+            } else if (Math.ceil(y) - y < 3*Math.ulp(y)) {
+                y = Math.ceil(y);
+            }
+            xa[i] = x;
+            ya[i] = y;
+        }
+    }
+    private void accumulate(int pix, double[] x, double[] y, boolean straddle) {
 	
 	// Handle pixels that go over the cuts in the projection
 	// plane by treating each region separately.
@@ -537,27 +555,12 @@ public class Clip extends Sampler {
 		    return;
 		}
 	        if (inProj.straddle(z)) {
-//		    System.err.println("Straddle for pixel:"+pix);
-//		    for (int i=0; i<x.length; i += 1) {
-//			System.err.println("   Input:"+x[i]+" "+y[i]);
-//		    }
-//		    for (int i=0; i<x.length; i += 1) {
-//			System.err.println("   IPlan:"+z[0][i]+" "+z[1][i]);
-//		    }
-		    double[][][] fields = inProj.straddleComponents(z);
+ 		    double[][][] fields = inProj.straddleComponents(z);
 		    for (int i=0; i<fields.length; i += 1) {
-//		        for (int j=0; j<fields[i][0].length; j += 1) {
-//			    System.err.println("   OPlan:"+fields[i][0][j]+" "+fields[i][1][i]);
-//		        }
 			// Convert from the standard projection plane to pixels.
-			inImgScaler.transform(fields[i], fields[i]);			
-//		        for (int j=0; j<fields[i][0].length; j += 1) {
-//			    System.err.println("   Oout :"+fields[i][0][j]+" "+fields[i][1][i]);
-//		        }
-			
+                        inImgScaler.transform(fields[i], fields[i]);
 			// Now add this bit in.
-		        accumulate(pix, fields[i][0], fields[i][1]);
-//			System.err.println("Accum:"+tArea+" "+depthArray[0]);
+		        accumulate(pix, fields[i][0], fields[i][1], true);
 		    }
 	            return;
 	        }
@@ -566,17 +569,18 @@ public class Clip extends Sampler {
 	    }
 	} 
 	
+        if (straddle) {
+            checkXY(x,y);
+        }
 	
 	// Find a bounding box for the pixel coordinates.
 	double minX = x[0];
 	double maxX = minX; 
 	double minY = y[0];
 	double maxY = minY;
-	
-	// Don't handle pixels where one of the corners is at
-	// NaN
 	double sum = minX+minY;
 	
+	
 	for (int k=1; k<x.length; k += 1) {
 	    
 	    // Note that a value can't simultaneously
@@ -642,8 +646,10 @@ public class Clip extends Sampler {
 	        tArea += pArea;
 	    
 	        for (int z=0; z<inDepth; z += 1) {
+                    // Put in cast to long to minimize chance
+                    // of exceeding int limits.
 		    double ival = pArea*
-		          inImage.getData(ix + iy*inWidth + z*inWidth*inHeight);
+		          inImage.getData((long)ix + (long)iy*inWidth + z*(long)inWidth*(long)inHeight);
 		    depthArray[z] += ival;
 		}
 	    }
@@ -720,7 +726,8 @@ public class Clip extends Sampler {
 		        tArea += factor;
 		    
 		        for (int z=0; z<inDepth; z += 1) {
-			    double ival   = factor*inImage.getData(m+n*inWidth+z*inWidth*inHeight);
+                            long index = m+(long)n*(long)inWidth+z*(long)inWidth*(long)inHeight;
+			    double ival   = factor*inImage.getData(index);
 			    depthArray[z] += ival; 
 		        }
 		    }
