@@ -240,6 +240,8 @@ public class NewTester {
             "mell-r", "mell-g", "mell-b"
         };
         
+        String[] hips = {"SwiftXRTCnt", "SwiftXRTInt", "SwiftXRTEXP"};
+        
         String[] goodsSurveys = new String[] {
             "GOODSNVLA", "GOODSMIPS", "GOODSACISFB", "GOODSACISSB","GOODSACISHB",
             "GOODS ACS B", "GOODS ACS V", "GOODS ACS I", "GOODS ACS Z",
@@ -389,6 +391,18 @@ public class NewTester {
             currentSettings.put("survey", survey);
             test(true);
         }
+        // Do HIPS surveys at a variety of scales.
+        base.up();
+        base.down();
+        for (double scale=.0001; scale < 10; scale *= 10 ) {
+            for (String survey: hips) {
+                currentSettings.remove("Size");
+                currentSettings.put("scale", ""+scale );
+                currentSettings.put("Position", "0,0");
+                currentSettings.put("Survey", survey);
+                test(true);
+            }
+        }
     }
 
     public int jpegSum(String jpegName) throws Exception {
@@ -1188,11 +1202,11 @@ public class NewTester {
             test(false);
             currentSettings.put("catalog", "I/284");
             test(false);
-            currentSettings.put("catalog", "http://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
+            currentSettings.put("catalog", "https://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
             test(false);
-            currentSettings.put("catalog", "ned,I/284,http://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
+            currentSettings.put("catalog", "ned,I/284,https://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
             test(false);
-            currentSettings.put("catalog", "ned,I/284,http://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
+            currentSettings.put("catalog", "ned,I/284,https://heasarc.gsfc.nasa.gov/cgi-bin/vo/cone/coneGet.pl?table=rosmaster&");
             test(false);
             currentSettings.put("catalog", "ned");
             currentSettings.put("catalogfields", "");
